This is an automated email from the ASF dual-hosted git repository.

astefanutti pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel-k.git

commit 3d19ae1bf1ed1754275c064aa0f11046cf0159e1
Author: Antonin Stefanutti <anto...@stefanutti.fr>
AuthorDate: Tue Mar 23 14:37:13 2021 +0100

    fix: Do not use operator version to compute Integration digest
---
 pkg/util/digest/digest.go | 5 ++---
 1 file changed, 2 insertions(+), 3 deletions(-)

diff --git a/pkg/util/digest/digest.go b/pkg/util/digest/digest.go
index 462aff2..2decff7 100644
--- a/pkg/util/digest/digest.go
+++ b/pkg/util/digest/digest.go
@@ -40,8 +40,8 @@ import (
 // Produces a digest that can be used as docker image tag
 func ComputeForIntegration(integration *v1.Integration) (string, error) {
        hash := sha256.New()
-       // Operator version is relevant
-       if _, err := hash.Write([]byte(defaults.Version)); err != nil {
+       // Integration version is relevant
+       if _, err := hash.Write([]byte(integration.Status.Version)); err != nil 
{
                return "", err
        }
        // Integration Kit is relevant
@@ -241,7 +241,6 @@ func sortedTraitSpecMapKeys(m map[string]v1.TraitSpec) 
[]string {
        return res
 }
 
-// ComputeSHA1 ---
 func ComputeSHA1(elem ...string) (string, error) {
        file := path.Join(elem...)
 

Reply via email to